@@ -499,13 +499,10 @@ gdk_x11_device_xi2_window_at_position (GdkDevice       *device,
   XIButtonState button_state = { 0 };
   XIModifierState mod_state;
   XIGroupState group_state;
-  Bool retval;
 
   display = gdk_device_get_display (device);
   screen = gdk_display_get_default_screen (display);
 
-  gdk_x11_display_error_trap_push (display);
-
   /* This function really only works if the mouse pointer is held still
    * during its operation. If it moves from one leaf window to another
    * than we'll end up with inaccurate values for win_x, win_y
@@ -552,18 +549,18 @@ gdk_x11_device_xi2_window_at_position (GdkDevice       *device,
           /* Free previous button mask, if any */
           g_free (button_state.mask);
 
-          retval = XIQueryPointer (xdisplay,
-                                   device_xi2->device_id,
-                                   xwindow,
-                                   &root, &child,
-                                   &xroot_x, &xroot_y,
-                                   &xwin_x, &xwin_y,
-                                   &button_state,
-                                   &mod_state,
-                                   &group_state);
-          if (!retval)
+          gdk_x11_display_error_trap_push (display);
+          XIQueryPointer (xdisplay,
+                          device_xi2->device_id,
+                          xwindow,
+                          &root, &child,
+                          &xroot_x, &xroot_y,
+                          &xwin_x, &xwin_y,
+                          &button_state,
+                          &mod_state,
+                          &group_state);
+          if (gdk_x11_display_error_trap_pop (display))
             continue;
-
           if (child != None)
             {
               pointer_window = child;
@@ -612,16 +609,17 @@ gdk_x11_device_xi2_window_at_position (GdkDevice       *device,
       last = xwindow;
       free (button_state.mask);
 
-      retval = XIQueryPointer (xdisplay,
-                               device_xi2->device_id,
-                               xwindow,
-                               &root, &xwindow,
-                               &xroot_x, &xroot_y,
-                               &xwin_x, &xwin_y,
-                               &button_state,
-                               &mod_state,
-                               &group_state);
-      if (!retval)
+      gdk_x11_display_error_trap_push (display);
+      XIQueryPointer (xdisplay,
+                      device_xi2->device_id,
+                      xwindow,
+                      &root, &xwindow,
+                      &xroot_x, &xroot_y,
+                      &xwin_x, &xwin_y,
+                      &button_state,
+                      &mod_state,
+                      &group_state);
+      if (gdk_x11_display_error_trap_pop (display))
         break;
 
       if (get_toplevel && last != root &&
@@ -635,25 +633,10 @@ gdk_x11_device_xi2_window_at_position (GdkDevice       *device,
 
   gdk_x11_display_ungrab (display);
 
-  if (gdk_x11_display_error_trap_pop (display) == 0)
-    {
-      window = gdk_x11_window_lookup_for_display (display, last);
-      impl = NULL;
-      if (window)
-        impl = GDK_WINDOW_IMPL_X11 (window->impl);
-
-      if (mask)
-        *mask = _gdk_x11_device_xi2_translate_state (&mod_state, &button_state, &group_state);
-
-      free (button_state.mask);
-    }
-  else
-    {
-      window = NULL;
-
-      if (mask)
-        *mask = 0;
-    }
+  window = gdk_x11_window_lookup_for_display (display, last);
+  impl = NULL;
+  if (window)
+    impl = GDK_WINDOW_IMPL_X11 (window->impl);
 
   if (win_x)
     *win_x = (window) ? (xwin_x / impl->window_scale) : -1;
@@ -661,6 +644,10 @@ gdk_x11_device_xi2_window_at_position (GdkDevice       *device,
   if (win_y)
     *win_y = (window) ? (xwin_y / impl->window_scale) : -1;
 
+  if (mask)
+    *mask = _gdk_x11_device_xi2_translate_state (&mod_state, &button_state, &group_state);
+
+  free (button_state.mask);
 
   return window;
 }
@@ -775,10 +762,10 @@ _gdk_x11_device_xi2_translate_state (XIModifierState *mods_state,
     {
       gint len, i;
 
-      /* We're only interested in the first 5 buttons */
-      len = MIN (5, buttons_state->mask_len * 8);
+      /* We're only interested in the first 3 buttons */
+      len = MIN (3, buttons_state->mask_len * 8);
 
-      for (i = 0; i < len; i++)
+      for (i = 1; i <= len; i++)
         {
           if (!XIMaskIsSet (buttons_state->mask, i))
             continue;
@@ -794,12 +781,6 @@ _gdk_x11_device_xi2_translate_state (XIModifierState *mods_state,
             case 3:
               state |= GDK_BUTTON3_MASK;
               break;
-            case 4:
-              state |= GDK_BUTTON4_MASK;
-              break;
-            case 5:
-              state |= GDK_BUTTON5_MASK;
-              break;
             default:
               break;
             }
