@@ -1925,7 +1925,7 @@ follow_if_link (GtkAboutDialog *about,
           GtkStateFlags state = gtk_widget_get_state_flags (GTK_WIDGET (about));
           gtk_style_context_get_color (context, state | GTK_STATE_FLAG_VISITED, &visited_link_color);
 
-          g_object_set (G_OBJECT (tag), "foreground-rgba", visited_link_color, NULL);
+          g_object_set (G_OBJECT (tag), "foreground-rgba", &visited_link_color, NULL);
 
           priv->visited_links = g_slist_prepend (priv->visited_links, g_strdup (uri));
         }
@@ -2288,6 +2288,7 @@ add_credits_section (GtkAboutDialog  *about,
 
       label = gtk_label_new (str->str);
       gtk_label_set_use_markup (GTK_LABEL (label), TRUE);
+      gtk_label_set_selectable (GTK_LABEL (label), TRUE);
       g_signal_connect_swapped (label, "activate-link",
                                 G_CALLBACK (emit_activate_link), about);
       g_string_free (str, TRUE);
