@@ -20,8 +20,6 @@
 #include "gtkcolorswatchprivate.h"
 
 #include "gtkcolorchooserprivate.h"
-#include "gtkroundedboxprivate.h"
-#include "gtkthemingbackgroundprivate.h"
 #include "gtkdnd.h"
 #include "gtkicontheme.h"
 #include "gtkmain.h"
@@ -30,6 +28,7 @@
 #include "gtkmenushell.h"
 #include "gtkprivate.h"
 #include "gtkintl.h"
+#include "gtkrenderprivate.h"
 #include "gtkwidgetprivate.h"
 #include "a11y/gtkcolorswatchaccessibleprivate.h"
 
@@ -40,10 +39,8 @@ struct _GtkColorSwatchPrivate
   gdouble radius[4];
   gchar *icon;
   guint    has_color        : 1;
-  guint    contains_pointer : 1;
   guint    use_alpha        : 1;
   guint    selectable       : 1;
-  guint    has_menu         : 1;
 
   GdkWindow *event_window;
 
@@ -55,8 +52,7 @@ enum
 {
   PROP_ZERO,
   PROP_RGBA,
-  PROP_SELECTABLE,
-  PROP_HAS_MENU
+  PROP_SELECTABLE
 };
 
 enum
@@ -86,7 +82,6 @@ gtk_color_swatch_init (GtkColorSwatch *swatch)
   swatch->priv = gtk_color_swatch_get_instance_private (swatch);
   swatch->priv->use_alpha = TRUE;
   swatch->priv->selectable = TRUE;
-  swatch->priv->has_menu = TRUE;
 
   gtk_widget_set_can_focus (GTK_WIDGET (swatch), TRUE);
   gtk_widget_set_has_window (GTK_WIDGET (swatch), FALSE);
@@ -104,45 +99,40 @@ gtk_color_swatch_init (GtkColorSwatch *swatch)
 }
 
 #define INTENSITY(r, g, b) ((r) * 0.30 + (g) * 0.59 + (b) * 0.11)
-#define ACTIVE_BADGE_RADIUS 10
+#define PIXBUF_SIZE 16
 
 static gboolean
 swatch_draw (GtkWidget *widget,
              cairo_t   *cr)
 {
   GtkColorSwatch *swatch = (GtkColorSwatch*)widget;
-  GtkThemingBackground background;
   gdouble width, height;
   GtkStyleContext *context;
   GtkStateFlags state;
   GtkIconTheme *theme;
+  GtkBorder border, padding;
+  GdkRectangle rect;
   GtkIconInfo *icon_info = NULL;
 
   theme = gtk_icon_theme_get_default ();
   context = gtk_widget_get_style_context (widget);
-  state = gtk_widget_get_state_flags (widget);
+  state = gtk_style_context_get_state (context);
   width = gtk_widget_get_allocated_width (widget);
   height = gtk_widget_get_allocated_height (widget);
 
-  cairo_save (cr);
-
-  gtk_style_context_save (context);
-  gtk_style_context_set_state (context, state);
-
-  _gtk_theming_background_init (&background, context,
-                                0, 0, width, height,
-                                GTK_JUNCTION_NONE);
+  gtk_render_background (context, cr, 0, 0, width, height);
 
   if (swatch->priv->has_color)
     {
       cairo_pattern_t *pattern;
       cairo_matrix_t matrix;
 
+      gtk_render_content_path (context, cr, 0, 0, width, height);
+
       if (swatch->priv->use_alpha)
         {
           cairo_save (cr);
 
-          _gtk_rounded_box_path (&background.padding_box, cr);
           cairo_clip_preserve (cr);
 
           cairo_set_source_rgb (cr, 0.33, 0.33, 0.33);
@@ -158,82 +148,55 @@ swatch_draw (GtkWidget *widget,
 
           cairo_restore (cr);
 
-          background.bg_color = swatch->priv->color;
+          gdk_cairo_set_source_rgba (cr, &swatch->priv->color);
         }
       else
         {
-          background.bg_color = swatch->priv->color;
-          background.bg_color.alpha = 1.0;
+          cairo_set_source_rgb (cr,
+                                swatch->priv->color.red,
+                                swatch->priv->color.green,
+                                swatch->priv->color.blue);
         }
 
-      _gtk_theming_background_render (&background, cr);
+      cairo_fill (cr);
     }
-  else
-    _gtk_theming_background_render (&background, cr);
 
   gtk_render_frame (context, cr, 0, 0, width, height);
 
-  if (gtk_widget_has_visible_focus (widget))
-    {
-      cairo_set_line_width (cr, 2);
-      if (swatch->priv->has_color && INTENSITY (swatch->priv->color.red, swatch->priv->color.green, swatch->priv->color.blue) < 0.5)
-        cairo_set_source_rgba (cr, 1., 1., 1., 0.4);
-      else
-        cairo_set_source_rgba (cr, 0., 0., 0., 0.4);
-        _gtk_rounded_box_shrink (&background.padding_box, 3, 3, 3, 3);
-        _gtk_rounded_box_path (&background.padding_box, cr);
-        cairo_stroke (cr);
-    }
-
   if (swatch->priv->icon)
     {
-      icon_info = gtk_icon_theme_lookup_icon (theme, swatch->priv->icon, 16,
+      icon_info = gtk_icon_theme_lookup_icon (theme, swatch->priv->icon, PIXBUF_SIZE,
                                               GTK_ICON_LOOKUP_GENERIC_FALLBACK
                                               | GTK_ICON_LOOKUP_USE_BUILTIN);
     }
   else if ((state & GTK_STATE_FLAG_SELECTED) != 0)
     {
-      GdkRGBA bg, border;
-      GtkBorder border_width;
       GIcon *gicon;
 
-      gtk_style_context_add_class (context, "color-active-badge");
-      _gtk_theming_background_init (&background, context,
-                                    (width - 2 * ACTIVE_BADGE_RADIUS) / 2, (height - 2 * ACTIVE_BADGE_RADIUS) / 2,
-                                    2 * ACTIVE_BADGE_RADIUS, 2* ACTIVE_BADGE_RADIUS,
-                                    GTK_JUNCTION_NONE);
+      gicon = g_themed_icon_new ("object-select-symbolic");
+      /* fallback for themes that don't have object-select-symbolic */
+      g_themed_icon_append_name (G_THEMED_ICON (gicon), "gtk-apply");
 
-      if (_gtk_theming_background_has_background_image (&background))
-        {
-          _gtk_theming_background_render (&background, cr);
-        }
-      else
-        {
-          gtk_style_context_get_background_color (context, state, &bg);
-          gtk_style_context_get_border_color (context, state, &border);
-          gtk_style_context_get_border (context, state, &border_width);
-
-          cairo_new_sub_path (cr);
-          cairo_arc (cr, width / 2, height / 2, ACTIVE_BADGE_RADIUS, 0, 2 * G_PI);
-          cairo_close_path (cr);
-          gdk_cairo_set_source_rgba (cr, &bg);
-          cairo_fill_preserve (cr);
-
-          gdk_cairo_set_source_rgba (cr, &border);
-          cairo_set_line_width (cr, border_width.left);
-          cairo_stroke (cr);
-
-          gicon = g_themed_icon_new ("object-select-symbolic");
-          /* fallback for themes that don't have object-select-symbolic */
-          g_themed_icon_append_name (G_THEMED_ICON (gicon), "gtk-apply");
-
-          icon_info = gtk_icon_theme_lookup_by_gicon (theme, gicon, 16,
-                                                      GTK_ICON_LOOKUP_GENERIC_FALLBACK
-                                                      | GTK_ICON_LOOKUP_USE_BUILTIN);
-          g_object_unref (gicon);
-        }
+      icon_info = gtk_icon_theme_lookup_by_gicon (theme, gicon, PIXBUF_SIZE,
+                                                  GTK_ICON_LOOKUP_GENERIC_FALLBACK
+                                                  | GTK_ICON_LOOKUP_USE_BUILTIN);
+      g_object_unref (gicon);
     }
 
+  /* now draw the overlay image */
+  gtk_style_context_get_border (context, state, &border);
+  gtk_style_context_get_padding (context, state, &padding);
+  rect.width = width - (border.left + border.right + padding.left + padding.right);
+  rect.height = height - (border.top + border.bottom + padding.top + padding.bottom);
+  rect.x = border.left + padding.left;
+  rect.y = border.top + padding.top;
+
+  gtk_style_context_save (context);
+  gtk_style_context_add_class (context, "overlay");
+  
+  gtk_render_background (context, cr, rect.x, rect.y, rect.width, rect.height);
+  gtk_render_frame (context, cr, rect.x, rect.y, rect.width, rect.height);
+
   if (icon_info != NULL)
     {
       GdkPixbuf *pixbuf;
@@ -244,15 +207,19 @@ swatch_draw (GtkWidget *widget,
       if (pixbuf != NULL)
         {
           gtk_render_icon (context, cr, pixbuf,
-                           (width - gdk_pixbuf_get_width (pixbuf)) / 2,
-                           (height - gdk_pixbuf_get_height (pixbuf)) / 2);
+                           rect.x + (rect.width - gdk_pixbuf_get_width (pixbuf)) / 2,
+                           rect.y + (rect.height - gdk_pixbuf_get_height (pixbuf)) / 2);
           g_object_unref (pixbuf);
         }
 
       g_object_unref (icon_info);
     }
 
-  cairo_restore (cr);
+  if (gtk_widget_has_visible_focus (widget))
+    {
+      gtk_render_focus (context, cr, 0, 0, width, height);
+    }
+
   gtk_style_context_restore (context);
 
   return FALSE;
@@ -390,7 +357,7 @@ swatch_key_press (GtkWidget   *widget,
       event->keyval == GDK_KEY_KP_Enter ||
       event->keyval == GDK_KEY_KP_Space)
     {
-      if (swatch->priv->has_color &&
+      if (swatch->priv->has_color && 
           swatch->priv->selectable &&
           (gtk_widget_get_state_flags (widget) & GTK_STATE_FLAG_SELECTED) == 0)
         gtk_widget_set_state_flags (widget, GTK_STATE_FLAG_SELECTED, FALSE);
@@ -409,8 +376,6 @@ static gboolean
 swatch_enter_notify (GtkWidget        *widget,
                      GdkEventCrossing *event)
 {
-  GtkColorSwatch *swatch = GTK_COLOR_SWATCH (widget);
-  swatch->priv->contains_pointer = TRUE;
   gtk_widget_set_state_flags (widget, GTK_STATE_FLAG_PRELIGHT, FALSE);
 
   return FALSE;
@@ -420,8 +385,6 @@ static gboolean
 swatch_leave_notify (GtkWidget        *widget,
                      GdkEventCrossing *event)
 {
-  GtkColorSwatch *swatch = GTK_COLOR_SWATCH (widget);
-  swatch->priv->contains_pointer = FALSE;
   gtk_widget_unset_state_flags (widget, GTK_STATE_FLAG_PRELIGHT);
 
   return FALSE;
@@ -554,7 +517,7 @@ tap_action (GtkGestureMultiPress *gesture,
     }
   else if (button == GDK_BUTTON_SECONDARY)
     {
-      if (swatch->priv->has_color && swatch->priv->has_menu)
+      if (swatch->priv->has_color)
         do_popup (GTK_WIDGET (swatch), button, gtk_get_current_event_time ());
     }
 }
@@ -612,7 +575,7 @@ swatch_realize (GtkWidget *widget)
   gtk_widget_set_window (widget, window);
   g_object_ref (window);
 
-  swatch->priv->event_window =
+  swatch->priv->event_window = 
     gdk_window_new (window,
                     &attributes, attributes_mask);
   gtk_widget_register_window (widget, swatch->priv->event_window);
@@ -678,9 +641,6 @@ swatch_get_property (GObject    *object,
     case PROP_SELECTABLE:
       g_value_set_boolean (value, gtk_color_swatch_get_selectable (swatch));
       break;
-    case PROP_HAS_MENU:
-      g_value_set_boolean (value, swatch->priv->has_menu);
-      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -703,9 +663,6 @@ swatch_set_property (GObject      *object,
     case PROP_SELECTABLE:
       gtk_color_swatch_set_selectable (swatch, g_value_get_boolean (value));
       break;
-    case PROP_HAS_MENU:
-      swatch->priv->has_menu = g_value_get_boolean (value);
-      break;
     default:
       G_OBJECT_WARN_INVALID_PROPERTY_ID (object, prop_id, pspec);
       break;
@@ -771,14 +728,10 @@ gtk_color_swatch_class_init (GtkColorSwatchClass *class)
   g_object_class_install_property (object_class, PROP_SELECTABLE,
       g_param_spec_boolean ("selectable", P_("Selectable"), P_("Whether the swatch is selectable"),
                             TRUE, GTK_PARAM_READWRITE));
-  g_object_class_install_property (object_class, PROP_HAS_MENU,
-      g_param_spec_boolean ("has-menu", P_("Has Menu"), P_("Whether the swatch should offer customization"),
-                            TRUE, GTK_PARAM_READWRITE));
 
   gtk_widget_class_set_accessible_type (widget_class, GTK_TYPE_COLOR_SWATCH_ACCESSIBLE);
 }
 
-
 /* Public API {{{1 */
 
 GtkWidget *
