@@ -44,9 +44,8 @@ static GtkCssValue *
 gtk_css_value_bg_size_compute (GtkCssValue             *value,
                                guint                    property_id,
                                GtkStyleProviderPrivate *provider,
-			       int                      scale,
-                               GtkCssStyle    *values,
-                               GtkCssStyle    *parent_values,
+                               GtkCssStyle             *style,
+                               GtkCssStyle             *parent_style,
                                GtkCssDependencies      *dependencies)
 {
   GtkCssValue *x, *y;
@@ -59,10 +58,10 @@ gtk_css_value_bg_size_compute (GtkCssValue             *value,
   x = y = NULL;
 
   if (value->x)
-    x = _gtk_css_value_compute (value->x, property_id, provider, scale, values, parent_values, &x_deps);
+    x = _gtk_css_value_compute (value->x, property_id, provider, style, parent_style, &x_deps);
 
   if (value->y)
-    y = _gtk_css_value_compute (value->y, property_id, provider, scale, values, parent_values, &y_deps);
+    y = _gtk_css_value_compute (value->y, property_id, provider, style, parent_style, &y_deps);
 
   *dependencies = _gtk_css_dependencies_union (x_deps, y_deps);
 
