@@ -100,9 +100,8 @@ gtk_css_value_color_free (GtkCssValue *color)
 static GtkCssValue *
 gtk_css_value_color_get_fallback (guint                    property_id,
                                   GtkStyleProviderPrivate *provider,
-				  int                      scale,
-                                  GtkCssStyle    *values,
-                                  GtkCssStyle    *parent_values)
+                                  GtkCssStyle             *style,
+                                  GtkCssStyle             *parent_style)
 {
   static const GdkRGBA transparent = { 0, 0, 0, 0 };
 
@@ -124,9 +123,8 @@ gtk_css_value_color_get_fallback (guint                    property_id,
         return _gtk_css_value_compute (_gtk_css_style_property_get_initial_value (_gtk_css_style_property_lookup_by_id (property_id)),
                                        property_id,
                                        provider,
-				       scale,
-                                       values,
-                                       parent_values,
+                                       style,
+                                       parent_style,
                                        NULL);
       default:
         if (property_id < GTK_CSS_PROPERTY_N_PROPERTIES)
@@ -302,9 +300,8 @@ static GtkCssValue *
 gtk_css_value_color_compute (GtkCssValue             *value,
                              guint                    property_id,
                              GtkStyleProviderPrivate *provider,
-			     int                      scale,
-                             GtkCssStyle    *values,
-                             GtkCssStyle    *parent_values,
+                             GtkCssStyle             *style,
+                             GtkCssStyle             *parent_style,
                              GtkCssDependencies      *dependencies)
 {
   GtkCssValue *resolved, *current;
@@ -316,9 +313,9 @@ gtk_css_value_color_compute (GtkCssValue             *value,
    */
   if (property_id == GTK_CSS_PROPERTY_COLOR)
     {
-      if (parent_values)
+      if (parent_style)
         {
-          current = gtk_css_style_get_value (parent_values, GTK_CSS_PROPERTY_COLOR);
+          current = gtk_css_style_get_value (parent_style, GTK_CSS_PROPERTY_COLOR);
           current_deps = GTK_CSS_EQUALS_PARENT;
         }
       else
@@ -329,7 +326,7 @@ gtk_css_value_color_compute (GtkCssValue             *value,
     }
   else
     {
-      current = gtk_css_style_get_value (values, GTK_CSS_PROPERTY_COLOR);
+      current = gtk_css_style_get_value (style, GTK_CSS_PROPERTY_COLOR);
       current_deps = GTK_CSS_DEPENDS_ON_COLOR;
     }
   
@@ -341,7 +338,7 @@ gtk_css_value_color_compute (GtkCssValue             *value,
                                            NULL);
 
   if (resolved == NULL)
-    return gtk_css_value_color_get_fallback (property_id, provider, scale, values, parent_values);
+    return gtk_css_value_color_get_fallback (property_id, provider, style, parent_style);
 
   return resolved;
 }
