@@ -58,9 +58,8 @@ struct _GtkCssImageClass
   GtkCssImage *(* compute)                         (GtkCssImage                *image,
                                                     guint                       property_id,
                                                     GtkStyleProviderPrivate    *provider,
-						    int                         scale,
-                                                    GtkCssStyle       *values,
-                                                    GtkCssStyle       *parent_values,
+                                                    GtkCssStyle                *style,
+                                                    GtkCssStyle                *parent_style,
                                                     GtkCssDependencies         *dependencies);
   /* compare two images for equality */
   gboolean     (* equal)                           (GtkCssImage                *image1,
@@ -96,9 +95,8 @@ double         _gtk_css_image_get_aspect_ratio     (GtkCssImage                *
 GtkCssImage *  _gtk_css_image_compute              (GtkCssImage                *image,
                                                     guint                       property_id,
                                                     GtkStyleProviderPrivate    *provider,
-						    int                        scale,
-                                                    GtkCssStyle       *values,
-                                                    GtkCssStyle       *parent_values,
+                                                    GtkCssStyle                *style,
+                                                    GtkCssStyle                *parent_style,
                                                     GtkCssDependencies         *dependencies);
 gboolean       _gtk_css_image_equal                (GtkCssImage                *image1,
                                                     GtkCssImage                *image2);
