@@ -1058,7 +1058,7 @@
  * text or icon itself, which is always rendered on top of the shadow layer.
  *
  * |[
- *   text-shadow: text-shadow: 1 1 0 blue, -4 -4 red;
+ *   text-shadow: 1 1 0 blue, -4 -4 red;
  * ]|
 
  * ## box-shadow: [ inset ] horizontal_offset vertical_offset [ blur_radius ] [ spread ] color;
@@ -1727,8 +1727,8 @@ gtk_css_provider_get_style_property (GtkStyleProvider *provider,
 					     val->section != NULL ? gtk_css_section_get_file (val->section) : NULL,
 					     val->value);
 
-	      found = _gtk_css_style_parse_value (value,
-						  scanner->parser);
+	      found = _gtk_css_style_funcs_parse_value (value,
+					                scanner->parser);
 
 	      gtk_css_scanner_destroy (scanner);
 
