@@ -46,6 +46,7 @@
 #include "gtktreeselection.h"
 #include "gtktreeview.h"
 #include "gtkwidget.h"
+#include "gtksettings.h"
 
 /**
  * SECTION:gtkfontchooserwidget
@@ -95,6 +96,8 @@ struct _GtkFontChooserWidgetPrivate
   GtkFontFilterFunc filter_func;
   gpointer          filter_data;
   GDestroyNotify    filter_data_destroy;
+
+  guint last_fontconfig_timestamp;
 };
 
 /* This is the initial fixed height and the top padding of the preview entry */
@@ -633,6 +636,21 @@ gtk_font_chooser_widget_load_fonts (GtkFontChooserWidget *fontchooser)
   gint n_families, i;
   PangoFontFamily **families;
   gchar *family_and_face;
+  guint fontconfig_timestamp;
+
+  g_object_get (gtk_widget_get_settings (GTK_WIDGET (fontchooser)),
+                "gtk-fontconfig-timestamp", &fontconfig_timestamp,
+                NULL);
+
+  /* The fontconfig timestamp is only set on systems with fontconfig; every
+   * other platform will set it to 0. For those systems, we fall back to
+   * reloading the fonts every time.
+   */
+  if (fontconfig_timestamp != 0 &&
+      priv->last_fontconfig_timestamp == fontconfig_timestamp)
+    return;
+
+  priv->last_fontconfig_timestamp = fontconfig_timestamp;
 
   list_store = GTK_LIST_STORE (priv->model);
 
@@ -936,10 +954,20 @@ gtk_font_chooser_widget_screen_changed (GtkWidget *widget,
                                         GdkScreen *previous_screen)
 {
   GtkFontChooserWidget *fontchooser = GTK_FONT_CHOOSER_WIDGET (widget);
+  GtkSettings *settings;
 
   if (GTK_WIDGET_CLASS (gtk_font_chooser_widget_parent_class)->screen_changed)
     GTK_WIDGET_CLASS (gtk_font_chooser_widget_parent_class)->screen_changed (widget, previous_screen);
 
+  if (previous_screen)
+    {
+      settings = gtk_settings_get_for_screen (previous_screen);
+      g_signal_handlers_disconnect_by_func (settings, gtk_font_chooser_widget_load_fonts, widget);
+    }
+  settings = gtk_widget_get_settings (widget);
+  g_signal_connect_object (settings, "notify::gtk-fontconfig-timestamp",
+                           G_CALLBACK (gtk_font_chooser_widget_load_fonts), widget, G_CONNECT_SWAPPED);
+
   if (previous_screen == NULL)
     previous_screen = gdk_screen_get_default ();
 
