@@ -333,22 +333,16 @@ gtk_widget_path_to_string (const GtkWidgetPath *path)
         {
           GFlagsClass *fclass;
           gint i;
-          gboolean appended;
 
-          appended = FALSE;
           fclass = g_type_class_ref (GTK_TYPE_STATE_FLAGS);
-          g_string_append_c (string, '[');
           for (i = 0; i < fclass->n_values; i++)
             {
               if (elem->state & fclass->values[i].value)
                 {
-                  if (appended)
-                    g_string_append_c (string, '|');
+                  g_string_append_c (string, ':');
                   g_string_append (string, fclass->values[i].value_nick);
-                  appended = TRUE;
                 }
             }
-          g_string_append_c (string, ']');
           g_type_class_unref (fclass);
         }
 
@@ -503,8 +497,8 @@ gtk_widget_path_iter_get_siblings (const GtkWidgetPath *path,
 {
   GtkPathElement *elem;
 
-  g_return_val_if_fail (path != NULL, G_TYPE_INVALID);
-  g_return_val_if_fail (path->elems->len != 0, G_TYPE_INVALID);
+  g_return_val_if_fail (path != NULL, NULL);
+  g_return_val_if_fail (path->elems->len != 0, NULL);
 
   if (pos < 0 || pos >= path->elems->len)
     pos = path->elems->len - 1;
