@@ -12,14 +12,11 @@
  * Library General Public License for more details.
  *
  * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * License along with this library. If not, see <http://www.gnu.org/licenses/>.
  */
 
 #include <string.h>
 #include <gtk/gtk.h>
-#include "prop-editor.h"
 
 static gboolean
 monospace_filter (const PangoFontFamily *family,
@@ -95,8 +92,6 @@ main (int argc, char *argv[])
   g_signal_connect (window, "delete-event",
                     G_CALLBACK (gtk_main_quit), NULL);
 
-  create_prop_editor (G_OBJECT (font_button), 0);
-
   gtk_main ();
 
   return 0;
